@@ -2,5 +2,5 @@
 # coding=utf-8
 # Stan 2013-04-24
 
-from tkpip import tkpip
-tkpip.main()
+from tkpip.tkpip import main
+main()
