@@ -11,15 +11,14 @@ from .backwardcompat import *
 
 
 # recipe from http://code.activestate.com/recipes/410646-tkinter-listbox-example/
-class ListBoxData(tkinter.Listbox):
+class ListBoxData(tk.Listbox):
     def __init__(self, master=None):
-        self.v = tkinter.Variable(master)
-        tkinter.Listbox.__init__(self, master, listvariable=self.v)
+        self.v = tk.Variable(master)
+        tk.Listbox.__init__(self, master, listvariable=self.v)
         ListBoxData.clear(self)
 
     def clear(self):
         self.v.set(())
-        self._selected = None
         self._datas = []
 
     def __iter__(self):
@@ -28,13 +27,19 @@ class ListBoxData(tkinter.Listbox):
             yield i, self.value(i), self.data(i)
 
     def value(self, pos):
-        pos = self.index(pos)
-        values = self.v.get()
-        return values[pos]
+        try:
+            pos = self.index(pos)
+            values = self.v.get()
+            return values[pos]
+        except ValueError as e: # !!! ValueError: invalid literal for int() with base 10: 'None'
+            print(pos, e)
 
     def data(self, pos):
-        pos = self.index(pos)
-        return self._datas[pos]
+        try:
+            pos = self.index(pos)
+            return self._datas[pos]
+        except ValueError as e: # !!! ValueError: invalid literal for int() with base 10: 'None'
+            print(pos, e)
 
     def setValue(self, pos, value):
         pos = self.index(pos)
@@ -47,14 +52,21 @@ class ListBoxData(tkinter.Listbox):
         self._datas[pos] = data
 
     def get_selected(self):
-        try:
-            value = self.value(self._selected)
-            data = self.data(self._selected)
-        except IndexError:
-            logging.warning("Index Error: {0}!".format(self._selected))
-            value = None
-            data = None
-        return self._selected, value, data
+        selection = self.curselection()
+        if selection:
+            selected = int(selection[0])
+
+            try:
+                value = self.value(selected)
+                data = self.data(selected)
+            except IndexError as e:
+                logging.warning("Index Error: {0} [{1}]!".format(selected, e))
+                value = None
+                data = None
+            return selected, value, data
+
+        else:
+            return None, None, None
 
 #     def delete(self, pos1, pos2=None):
 #         pos1 = self.index(pos1)
@@ -68,7 +80,7 @@ class ListBoxData(tkinter.Listbox):
 
     def insert_data(self, pos, label, data, **kw):
         pos = self.index(pos)
-        tkinter.Listbox.insert(self, pos, label, **kw)
+        tk.Listbox.insert(self, pos, label, **kw)
         self._datas.insert(pos+1, data)
 
         # itemconfig
@@ -80,10 +92,10 @@ class ListBoxData(tkinter.Listbox):
     def insert_items(self, items):
         if isinstance(items, list):
             for key in sorted(items):
-                self.insert(tkinter.END, key)
+                self.insert(tk.END, key)
         elif isinstance(items, dict):
             for key in sorted(items.keys()):
-                self.insert_data(tkinter.END, key, items.get(key))
+                self.insert_data(tk.END, key, items[key])
 
 
 def test():
@@ -91,7 +103,7 @@ def test():
 
     # Listbox Widget
     listbox1 = ListBoxData(root)
-    lb1_yscrollbar = Scrollbar(root, orient=tkinter.VERTICAL, command=listbox1.yview)
+    lb1_yscrollbar = Scrollbar(root, orient=tk.VERTICAL, command=listbox1.yview)
     listbox1['yscrollcommand'] = lb1_yscrollbar.set
 
     # Pack
